@@ -34,13 +34,17 @@ This module exports several important base classes:
                         a subclass is used, a warning message will be
                         printed.
 
+    RemovedCommand - an abstract subclass of KickstartCommand that should
+                     be subclassed to update the description with the version
+                     it was removed in.
+                     Any use of the command will raise an error.
+
     KickstartCommand - The base abstract class for all kickstart commands.
                        Command objects are contained within a BaseHandler
                        object.
 """
 from pykickstart.i18n import _
 
-import six
 import warnings
 from pykickstart import __version__
 from pykickstart.errors import KickstartParseError, KickstartParseWarning, KickstartDeprecationWarning
@@ -214,6 +218,38 @@ class DeprecatedCommand(KickstartCommand):
         """Print a warning message if the command is seen in the input file."""
         mapping = {"lineno": self.lineno, "cmd": self.currentCmd}
         warnings.warn(_("Ignoring deprecated command on line %(lineno)s:  The %(cmd)s command has been deprecated and no longer has any effect.  It may be removed from future releases, which will result in a fatal error from kickstart.  Please modify your kickstart file to remove this command.") % mapping, KickstartDeprecationWarning)
+        return None
+
+class RemovedCommand(KickstartCommand):
+    """Specify that a command has been removed and no longer has any function.
+       Any command that is removed should be subclassed from this class, and
+       should set its description to add the version that the command was removed in.
+       This is an abstract class.
+    """
+    def __init__(self, writePriority=None, *args, **kwargs):
+        # We don't want people using this class by itself.
+        if self.__class__ is RemovedCommand:
+            raise TypeError("RemovedCommand is an abstract class.")
+
+        # Create a new RemovedCommand instance.
+        KickstartCommand.__init__(self, writePriority, *args, **kwargs)
+
+    def dataList(self):
+        """Override the method of the removed command."""
+        return None
+
+    @property
+    def dataClass(self):
+        """Override the attribute of the removed command."""
+        return None
+
+    def __str__(self):
+        """Placeholder since RemovedCommands don't work anymore."""
+        return ""
+
+    def parse(self, args):
+        """Raise an error if the command is found in the input file"""
+        raise KickstartParseError(_("%s has been removed.") % self.currentCmd, lineno=self.lineno)
 
 ###
 ### HANDLERS
@@ -264,10 +300,7 @@ class KickstartHandler(KickstartObject):
 
         for prio in lst:
             for obj in self._writeOrder[prio]:
-                obj_str = obj.__str__()
-                if isinstance(obj_str, six.text_type) and not six.PY3:
-                    obj_str = obj_str.encode("utf-8")
-                retval += obj_str
+                retval += obj.__str__()
 
         return retval
 
@@ -298,12 +331,8 @@ class KickstartHandler(KickstartObject):
         # off the version part from the front of the name.
         if cmdObj.__class__.__name__.find("_") != -1:
             name = cmdObj.__class__.__name__.split("_", 1)[1]
-            if not six.PY3:
-                name = unicode(name)    # pylint: disable=undefined-variable
         else:
             name = cmdObj.__class__.__name__.lower()
-            if not six.PY3:
-                name = unicode(name)    # pylint: disable=undefined-variable
 
         setattr(self, name.lower(), cmdObj)
 
@@ -469,10 +498,7 @@ class BaseHandler(KickstartHandler):
         retval += KickstartHandler.__str__(self)
 
         for script in self.scripts:
-            script_str = script.__str__()
-            if isinstance(script_str, six.text_type) and not six.PY3:
-                script_str = script_str.encode("utf-8")
-            retval += script_str
+            retval += script.__str__()
 
         if self._null_section_strings:
             retval += "\n"
