@@ -15,15 +15,15 @@
 # Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Red Hat
 # trademarks that are incorporated in the source code or documentation are not
 # subject to the GNU General Public License and may only be used or replicated
-# with the express permission of Red Hat, Inc. 
+# with the express permission of Red Hat, Inc.
 #
-from pykickstart.base import *
-from pykickstart.constants import *
-from pykickstart.errors import *
-from pykickstart.options import *
+from pykickstart.version import RHEL5
+from pykickstart.base import KickstartCommand
+from pykickstart.constants import KS_INSTKEY_SKIP
+from pykickstart.errors import KickstartParseError
+from pykickstart.options import KSOptionParser
 
-import gettext
-_ = lambda x: gettext.ldgettext("pykickstart", x)
+from pykickstart.i18n import _
 
 class RHEL5_Key(KickstartCommand):
     removedKeywords = KickstartCommand.removedKeywords
@@ -40,24 +40,28 @@ class RHEL5_Key(KickstartCommand):
 
         if self.key == KS_INSTKEY_SKIP:
             retval += "key --skip\n"
-        elif self.key != "":
+        elif self.key:
             retval += "key %s\n" % self.key
 
         return retval
 
     def _getParser(self):
-        op = KSOptionParser()
-        op.add_option("--skip", action="store_true", default=False)
+        op = KSOptionParser(prog="key", description="set or skip the software installation key", version=RHEL5)
+        op.add_argument("--skip", action="store_true", default=False,
+                        version=RHEL5, help="Skip the software installation key")
         return op
 
     def parse(self, args):
-        (opts, extra) = self.op.parse_args(args=args, lineno=self.lineno)
-        self._setToSelf(self.op, opts)
+        (ns, extra) = self.op.parse_known_args(args=args, lineno=self.lineno)
+        self.set_to_self(ns)
 
         if self.skip:
             self.key = KS_INSTKEY_SKIP
         elif len(extra) != 1:
-            raise KickstartValueError, formatErrorMsg(self.lineno, msg=_("Kickstart command %s requires one argument") % "key")
+            raise KickstartParseError(_("Kickstart command %s requires one argument") % "key", lineno=self.lineno)
+        elif any(arg for arg in extra if arg.startswith("-")):
+            mapping = {"command": "key", "options": extra}
+            raise KickstartParseError(_("Unexpected arguments to %(command)s command: %(options)s") % mapping, lineno=self.lineno)
         else:
             self.key = extra[0]
 
