@@ -36,7 +36,7 @@ from pykickstart.constants import KS_SCRIPT_PRE, KS_SCRIPT_POST, KS_SCRIPT_TRACE
                                   KS_BROKEN_IGNORE, KS_BROKEN_REPORT
 from pykickstart.errors import KickstartParseError, KickstartDeprecationWarning
 from pykickstart.options import KSOptionParser
-from pykickstart.version import FC4, F7, F9, F18, F21, F22, F24, F32, RHEL6, RHEL7
+from pykickstart.version import FC4, F7, F9, F18, F21, F22, F24, F32, F34, RHEL6, RHEL7
 from pykickstart.i18n import _
 
 class Section(object):
@@ -239,7 +239,7 @@ class PreScriptSection(ScriptSection):
 
         .. note::
 
-            The pre-install script is not run in the chroot environment.
+            The pre-installation script is not run in the chroot environment.
     """
     _epilog = """
     Example
@@ -387,7 +387,7 @@ class OnErrorScriptSection(ScriptSection):
     a bug in the installer.  Some examples of these situations include errors in
     packages that have been requested to be installed, failures when starting VNC
     when requested, and error when scanning storage.  When these situations happen,
-    installaton cannot continue.  The installer will run all %onerror scripts in
+    installation cannot continue.  The installer will run all %onerror scripts in
     the order they are provided in the kickstart file.
 
     In addition, %onerror scripts will be run on a traceback as well.  To be exact,
@@ -436,6 +436,17 @@ class TracebackScriptSection(OnErrorScriptSection):
         OnErrorScriptSection._resetScript(self)
         self._script["type"] = KS_SCRIPT_TRACEBACK
 
+    def handleHeader(self, lineno, args):
+        super().handleHeader(lineno, args)
+
+        if self.version < F34:
+            return
+
+        warnings.warn("The %traceback section has been deprecated. It may be removed in the "
+                      "future, which will result in a fatal error from kickstart. Please modify "
+                      "your kickstart file to use the %onerror section instead.",
+                      KickstartDeprecationWarning)
+
 class PackageSection(Section):
     sectionOpen = "%packages"
     _title = "Package Selection"
@@ -771,8 +782,8 @@ class PackageSection(Section):
         for option, new_option in \
                 {"--instLangs": "--inst-langs", "--excludeWeakdeps": "--exclude-weakdeps"}.items():
             if option in args:
-                warnings.warn(_("The %(option)s option on line %(lineno)s will be deprecated in"
-                                "future releases. Please modify your kickstart file to replace"
+                warnings.warn(_("The %(option)s option on line %(lineno)s will be deprecated in "
+                                "future releases. Please modify your kickstart file to replace "
                                 "this option with its preferred alias %(new_option)s.")
                               % {"option": option, "lineno": lineno, "new_option": new_option},
                               KickstartDeprecationWarning)
