@@ -1,4 +1,3 @@
-import six
 import sys
 import unittest
 import tempfile
@@ -123,6 +122,24 @@ class StringToVersion_TestCase(CommandTest):
         # pass - F29
         self.assertEqual(stringToVersion("Fedora 29"), F29)
         self.assertEqual(stringToVersion("F29"), F29)
+        # pass - F30
+        self.assertEqual(stringToVersion("Fedora 30"), F30)
+        self.assertEqual(stringToVersion("F30"), F30)
+        # pass - F31
+        self.assertEqual(stringToVersion("Fedora 31"), F31)
+        self.assertEqual(stringToVersion("F31"), F31)
+        # pass - F32
+        self.assertEqual(stringToVersion("Fedora 32"), F32)
+        self.assertEqual(stringToVersion("F32"), F32)
+        # pass - F33
+        self.assertEqual(stringToVersion("Fedora 33"), F33)
+        self.assertEqual(stringToVersion("F33"), F33)
+        # pass - F34
+        self.assertEqual(stringToVersion("Fedora 34"), F34)
+        self.assertEqual(stringToVersion("F34"), F34)
+        # pass - F35
+        self.assertEqual(stringToVersion("Fedora 35"), F35)
+        self.assertEqual(stringToVersion("F35"), F35)
 
         # pass - RHEL3
         self.assertEqual(stringToVersion("Red Hat Enterprise Linux 3"), RHEL3)
@@ -176,6 +193,13 @@ class StringToVersion_TestCase(CommandTest):
             self.assertEqual(stringToVersion("Red Hat Enterprise Linux 8.%s" % MINOR), RHEL8)
         self.assertEqual(stringToVersion("RHEL8"), RHEL8)
 
+        # pass - RHEL9
+        self.assertEqual(stringToVersion("Red Hat Enterprise Linux 9"), RHEL9)
+        for MINOR in range(1,10):
+            self.assertEqual(stringToVersion("Red Hat Enterprise Linux 9.%s" % MINOR), RHEL9)
+        self.assertEqual(stringToVersion("RHEL9"), RHEL9)
+
+
 class VersionToString_TestCase(CommandTest):
     def runTest(self):
 
@@ -222,7 +246,12 @@ class VersionToString_TestCase(CommandTest):
         self.assertEqual(versionToString(F28, skipDevel=True), "F28")
         self.assertEqual(versionToString(F29, skipDevel=True), "F29")
         self.assertEqual(versionToString(F30, skipDevel=True), "F30")
-        self.assertEqual(versionToString(F30, skipDevel=False), "DEVEL")
+        self.assertEqual(versionToString(F31, skipDevel=True), "F31")
+        self.assertEqual(versionToString(F32, skipDevel=True), "F32")
+        self.assertEqual(versionToString(F33, skipDevel=True), "F33")
+        self.assertEqual(versionToString(F34, skipDevel=True), "F34")
+        self.assertEqual(versionToString(F35, skipDevel=True), "F35")
+        self.assertEqual(versionToString(F35, skipDevel=False), "DEVEL")
         # RHEL series
         self.assertEqual(versionToString(RHEL3), "RHEL3")
         self.assertEqual(versionToString(RHEL4), "RHEL4")
@@ -230,6 +259,7 @@ class VersionToString_TestCase(CommandTest):
         self.assertEqual(versionToString(RHEL6), "RHEL6")
         self.assertEqual(versionToString(RHEL7), "RHEL7")
         self.assertEqual(versionToString(RHEL8), "RHEL8")
+        self.assertEqual(versionToString(RHEL9), "RHEL9")
 
         # fail
         self.assertRaises(KickstartVersionError, versionToString, 47)
@@ -272,8 +302,7 @@ class versionFromFile_TestCase(CommandTest):
 
         def write_ks_cfg(buf):
             (fd, name) = tempfile.mkstemp(prefix="ks-", suffix=".cfg", dir="/tmp", text=True)
-            if six.PY3:
-                buf = buf.encode(sys.getdefaultencoding())
+            buf = buf.encode(sys.getdefaultencoding())
             os.write(fd, buf)
             os.close(fd)
             return name
